// OPL Library
package psion.opl;

import java.io.*;
import java.util.*;

/**
 * The OPL class provides an interface to Psion's OPL functions from Java.
 * This class is intended as a "fast and efficient" way to do graphics on a
 * Series 3x machine, as the AWT involves way to much baggage to run anything
 * in the memory available.  Most of the methods in this class are implemented
 * as native code inside the Taurus Java VM.  A version of the class library is
 * available which is written entirely in Java and is intended to emululate the
 * Psion on machines capable of running the AWT (part of the opl2java project)
 *.
 * @author  Taurus Software
 * @version 1.00, 05/11/99
 * @since   Taurus OPL Library 1.0
 */
public class OPL
{	
    /**
     * Positions the graphics cursor at coordinates x, y.
     *
     * @param   x   The x-coordinate.
     * @param   y   The y-coordinate.
     */
	public static native void gAt( int x, int y );

    /**
     * Draws a box width x height pixels from the current graphics position.
     *
     * @param   width   The width of the box.
     * @param   height  The height of the box.
     */
	public static native void gBox( int width, int height );
	
	/**
	 * Creates a new window at coordinates x, y of width, w, and height, h.  If
	 * v is 1, then the window is visible.  If g is 1, then the window will
	 * have a grey plane.
	 *
	 * @param   x   X-coordinate of window.
	 * @param   y   Y-coordinate of window.
	 * @param   w   width of window.
	 * @param   h   height of window.
	 * @param   v   visible flag.
	 * @param   g   grey flag.
	 *
	 * @return  The handle of the newly created window.
	 */
	public static native int gCreate( int x, int y, int w, int h, int v, int grey );
	
	/**
     * Draws a filled box width x height pixels from the current graphics
     * position.
     *
     * @param   width   The width of the box.
     * @param   height  The height of the box.
	 */
	public static native void gFill( int width, int height, int mode );
	
	/**
	 * Sets which graphics planes are to be drawn on.  If mode is 0, then
	 * drawing takes place on the black plane only.  If mode is 1, then only
	 * the grey plane is used, and if it is 2, then both black and grey planes
	 * are used.
	 *
	 * @param   mode    Drawing mode to use.
	 */
    public static native void gGrey( int mode );
	
	/**
     * Draws a line from the current graphics position a distance of dx pixels
     * horizontally and dy pixels vertically.
     *
     * @param   dx   Horizontal distance.
     * @param   dy   Vertical distance.
	 */
    public static native void gLineBy( int dx, int dy );

	/**
     * Prints the given text at the current graphics position.
     *
     * @param   s   Text string.
	 */
    public static native void gPrint( String s /*, ... */ );
	
	/**
	 * NOT IMPLEMENTED
	 */
    public static void gTMode( int mode )  {}
	
	/**
	 * NOT IMPLEMENTED
	 */
    public static void print( String s /*, ... */ ) {}


    /* ================== OPLlib Environment Functions ======================== */
	
	/**
	 * PRIVATE FUNCTION - DO NOT USE
	 */
    public static boolean lib_init( String program_name ) { return true; }
}
